var group__kl__neighborhood =
[
    [ "Computing MFE representatives of a Distance Based Partitioning", "group__kl__neighborhood__mfe.html", "group__kl__neighborhood__mfe" ],
    [ "Computing Partition Functions of a Distance Based Partitioning", "group__kl__neighborhood__pf.html", "group__kl__neighborhood__pf" ],
    [ "Stochastic Backtracking of Structures from Distance Based Partitioning", "group__kl__neighborhood__stochbt.html", "group__kl__neighborhood__stochbt" ],
    [ "2Dfold.h", "2Dfold_8h.html", null ],
    [ "2Dpfold.h", "2Dpfold_8h.html", null ]
];